Using Different Storage Backends
================================

LMCache supports various storage backends to offload and share KV cache data.

Supported Backends
-------------------------

.. toctree::
   :maxdepth: 1

   cpu_ram
   custom_backend
   eic
   gds
   infinistore
   local_storage
   mock
   mooncake
   nixl
   redis
   s3
   sagemaker_hyperpod
   valkey
   weka
   
   
  
